--[[
 This file is part of DungeonTime.

    DungeonTime is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DungeonTime is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DungeonTime.  If not, see <http://www.gnu.org/licenses/>.
]]

--- **DungeonTime** displays current LFG Tool times for your queue as well as plays a sound when group is found.

DungeonTime = LibStub("AceAddon-3.0"):NewAddon("DungeonTime", "AceConsole-3.0", "AceEvent-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("DungeonTime");

-- Sound to play when LFG event shows.
local sound_file = "Interface\\AddOns\\DungeonTime\\warning.ogg";

--- Registers the chat command /dt when the addon initializes.
function DungeonTime:OnInitialize()
	DungeonTime:RegisterChatCommand("dt", "ChatCommand");
end;

--- Registers the event LFG_PROPOSAL_SHOW when the addon enables.
function DungeonTime:OnEnable()
	DungeonTime:RegisterEvent("LFG_PROPOSAL_SHOW", "LFGWarning");
end;

--- Unregisters the event LFG_PROPOSAL_SHOW when the addon is disabled.
function DungeonTime:OnDisable()
	DungeonTime:UnregisterEvent("LFG_PROPOSAL_SHOW");
end;

--- Calls the function Run when used the chat command /dt
-- @param input of the /dt command (not used)
function DungeonTime:ChatCommand(input)
	DungeonTime:Run()
end;

--- Check the LFG queue status and print the info.
function DungeonTime:Run()
	local isLeader, isTank, isHealer, isDPS = GetLFGRoles();
	local waitTime;
	local hasData, leaderNeeds, tankNeeds, healerNeeds, dpsNeeds, instanceType, instanceName, averageWait, tankWait, healerWait, damageWait, myWait, queuedTime = GetLFGQueueStats();
	if hasData then
		if isTank and tankWait ~= nil then
			DungeonTime:Print(L["Tank wait: "]..DungeonTime:FormatTime(tankWait));
		end;
		if isHealer and healerWait ~= nil then
			DungeonTime:Print(L["Heal wait: "]..DungeonTime:FormatTime(healerWait));
		end;
		if isDPS and damageWait ~= nil then
			DungeonTime:Print(L["DPS wait: "]..DungeonTime:FormatTime(damageWait));
		end;
		DungeonTime:Print(L["Average wait: "]..DungeonTime:FormatTime(averageWait));
		DungeonTime:Print(L["Predicted wait: "]..DungeonTime:FormatTime(myWait));
		waitTime = GetTime() - queuedTime;
		DungeonTime:Print(L["Time on queue: "]..DungeonTime:FormatTime(waitTime));
	else
		DungeonTime:Print(L["You're not queued or no data available yet!"]);
	end;
end;

--- Convert a given time to mmss.
-- @param time in seconds
-- @usage convert the time given to mmss format
-- @return minutes:seconds
function DungeonTime:FormatTime(timer)
	local seconds, minutes;
	if timer ~= -1 then
		minutes = tonumber(string.format("%." .. (0) .. "f", timer/60));
		seconds = timer % 60;
		if seconds < 10 then
			seconds = "0"..seconds;
		end;
		return(minutes..":"..seconds);
	else
		return("N/A");
	end;
end;

--- Plays a sound file defined as local variable sound_file.
function DungeonTime:LFGWarning()
	PlaySoundFile(sound_file);
end;
